@@ -5,7 +5,8 @@ import logging
 from contextlib import contextmanager
 from copy import copy
 
-from .ldapfilter import Filter, OrGroup, BitAndFilter, UserAccountControl
+from .adman import DISABLED_USER_FILTER
+from .ldapfilter import Filter, OrGroup, BitAndFilter
 from .util import single
 
 
@@ -69,7 +70,7 @@ class AssignerBase:
         self.onchange = onchange
 
         self.user_filt  = ~OrGroup(*(Filter('CN={}'.format(u)) for u in EXCLUDE_CN_USERS))
-        self.user_filt &= ~BitAndFilter('userAccountControl', UserAccountControl.ACCOUNTDISABLE)
+        self.user_filt &= ~DISABLED_USER_FILTER
 
     def get_users(self, all_users=False, rdn=None, scope=None):
         filt = None if all_users else self.user_filt
